pub struct PostgresSinkConfig {
pub connection_url: String,
pub table_name: String,
pub column_mapping: PostgresColumnMapping,
pub batch_size: usize,
pub max_connections: u32,
}Expand description
Configuration for the PostgreSQL sink.
Fields
connection_url: StringPostgreSQL connection URL (e.g. postgres://user:pass@host/db).
table_name: StringTarget table name.
column_mapping: PostgresColumnMappingHow to map JSON records to columns.
batch_size: usizeMaximum number of rows per INSERT statement. Defaults to 500.
max_connections: u32Maximum number of connections in the pool. Defaults to 5.
Implementations
Sourceimpl PostgresSinkConfig
impl PostgresSinkConfig
Sourcepub fn new(
connection_url: impl Into<String>,
table_name: impl Into<String>,
) -> Self
pub fn new( connection_url: impl Into<String>, table_name: impl Into<String>, ) -> Self
Create a new config with required fields and sensible defaults.
Sourcepub fn column_mapping(self, mapping: PostgresColumnMapping) -> Self
pub fn column_mapping(self, mapping: PostgresColumnMapping) -> Self
Set the column mapping strategy.
Sourcepub fn batch_size(self, n: usize) -> Self
pub fn batch_size(self, n: usize) -> Self
Set the batch size for INSERT statements.
Sourcepub fn max_connections(self, n: u32) -> Self
pub fn max_connections(self, n: u32) -> Self
Set the maximum number of connections in the pool.